CommandBuffer class

Constructors

CommandBuffer()

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addComponent(EntityID entityID, Component component) → void
addComponents(EntityID entityID, List<Component> components) → void
apply(World world) → void
clear() → void
createEntities(List<List<Component>> entities) → void
createEntityWith(List<Component> components) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeComponent(EntityID entityID, Type componentType) → void
removeComponents(EntityID entityID, List<Type> componentTypes) → void
removeEntity(EntityID entityID) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited