InstantChanges class

Constructors

InstantChanges(World world)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
world World
final

Methods

addComponent(EntityID entityID, Component component) → void
addComponents(EntityID entityID, List<Component> components) → void
createEntities(List<List<Component>> entitiesComponents) List<EntityID>
createEntityWith(List<Component> components) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeComponent<T extends Component>(EntityID entityID) → void
removeComponentByType(EntityID entityID, Type t) → void
removeComponents(EntityID entityID, {required List<Type> components}) → void
removeEntities(Iterable<EntityID> entities) → void
removeEntity(EntityID entityID) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited