World class

Constructors

World()

Properties

archetypeCount int
no setter
commands CommandBuffer
final
componentTypesCount int
no setter
entityCount int
no setter
hashCode int
The hash code for this object.
no setterinherited
instant InstantChanges
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
no setter

Methods

addResource<T>(T resource, {String tag = ""}) → T
addSystem(System system, {String tag = ""}) → void
applyCommands() → void
clearAll() → void
clearEntities() → void
clearResources() → void
clearSystems() → void
componentColumn(ComponentID id, SetHash hash) int
componentID<T extends Component>() ComponentID?
createEntity() int
findMatchingArchetypes(SetHash hash) List<Archetype>
getComponent<T extends Component>(EntityID entityID) → T?
getComponentID(Type type) ComponentID?
getResource<T>({String tag = ""}) → T?
isAlive(EntityID entityID) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(List<Type> types) List<QueryRow>
queryCount(List<Type> types) int
queryCountWithParams(QueryParams params) int
queryEach(QueryParams params, void fn(QueryRowView row)) → void
queryEachPairs(QueryParams aParams, QueryParams bParams, void fn(QueryRowView a, QueryRowView b)) → void
queryEachPairsSelf(QueryParams params, void fn(QueryRowView a, QueryRowView b)) → void
queryRaw(QueryParams params) List<Component>
queryWithParams(QueryParams params) List<QueryRow>
removeResource<T>({String tag = ""}) → T?
runSystemOnce<T>(System system, {required T args}) → void
toString() String
A string representation of this object.
inherited
update<T>(T args, {String tag = ""}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited